==> SexyMap-v9.2.15.zip: SexyMap/localization/deDE.lua <==

if GetLocale() ~= "deDE" then return end
local _, sm = ...
local L = sm.L
--L.dayNightButton = "Day/Night Indicator"
--L.classicLFGButton = "Classic LFG Button (When Available)"
--L.classicPVPButton = "Classic PvP Button (When Available)"
L["1. Background"] = "1. Hintergrund"
L["2. Border"] = "2. Rahmen"
L["3. Artwork"] = "3. Vorlagen"
L["4. Overlay"] = "4. Überlagerung"
L["5. Highlight"] = "5. Hervorhebung"
L["Add Blend (additive)"] = "Überblendung hinzufügen (additiv)"
L["Addon Buttons"] = "AddOn-Knöpfe"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "Ein globales Profil existiert bereits. Du wechselst auf dieses Profil und das Interface wird neu geladen, bist du dir sicher?"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "Erlaube SexyMap, das Bewegen/Ziehen von Knöpfen an der Minikarte zu übernehmen. Deaktiviere diese Option, wenn du einen anderen Mod/AddOn benutzt, um die Minikartenknöpfe zu positionieren."
L["Alpha Key (1-bit alpha)"] = "Alpha-Wert (1-bit alpha)"
L["Always"] = "Immer"
L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "Bist du dir sicher, dass du zurück auf das charakterspezifische Profil wechseln willst? Dies wird dein Interface neu laden."
L["Armored Man"] = "Haltbarkeitsfigur"
L["A static amount to rotate the texture by."] = "Ein statischer Wert, um den die Textur gedreht werden soll."
L["Auto Zoom-Out Delay"] = "Auto-Herauszoom-Verzögerung"
L["Backdrop Color"] = "Hintergrundfarbe"
L["Backdrop Insets"] = "Hintergründe"
L["Background Color"] = "Hintergrundfarbe"
L["Background/edge"] = "Hintergrund/Kante"
L["Background Texture"] = "Hintergrundtextur"
L["Blend Mode"] = "Überblendmodus"
L["Blend (normal)"] = "Überblendung (normal)"
L["Border Color"] = "Rahmenfarbe"
L["Border Edge Size"] = "Randkantengröße"
L["Borders"] = "Rahmen"
L["Border Texture"] = "Rahmentextur"
L["Boss Frames"] = "Bossfenster"
L["Buttons"] = "Knöpfe"
L["Calendar"] = "Kalender"
L["Challenge Mode Button (When Available)"] = "Herausforderungsmodus-Knopf (Wenn verfügbar)"
L["Circle"] = "Kreis"
L["Clamp to screen"] = "Am Bildschirm befestigen"
L["Clear & start over"] = "Leeren & neu anfangen"
L["Clear the current borders and start fresh"] = "Die aktuellen Rahmen löschen und neu anfangen"
L["Clock"] = "Uhr"
L["Coordinates"] = "Koordinaten"
L["Copy a Profile"] = "Kopiere ein Profil"
L["Copying this profile will reload your UI, are you sure?"] = "Das Kopieren dieses Profils wird dein Interface neu laden, bist du dir sicher?"
L["Create a new border"] = "Neuen Rahmen erstellen"
L["Current Borders"] = "Aktuelle Rahmen"
L["Default Presets"] = "Standard-Voreinstellungen"
L["Delete"] = "Löschen"
L["Delete a Profile"] = "Lösche ein Profil"
L["Diamond"] = "Diamant"
L["Disable (opaque)"] = "Deaktivieren (lichtdicht/opaque)"
L["Disable Rotation"] = "Rotation deaktivieren"
L["Drag Radius"] = "Bewegungs-Radius"
L["Dungeon Difficulty Indicator (When Available)"] = "Instanzschwierigkeitsanzeige (wenn verfügbar)"
L["Dynamic Buttons"] = "Dynamische Knöpfe"
L["Enable"] = "Aktivieren"
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "Aktiviere einen Hintergrund und Rahmen für die Minikarte. Dies erleichtert die Konfiguration von eckigen Rahmen."
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "Aktiviere eine HUD-Minikarte. Diese Anzeige ist sehr nützlich für Sammelberufe, jedoch kann das HUD und die normale Minikarte nicht gleichzeitig angezeigt werden. Die normale Minikarte ist während der HUD-Anzeige deaktiviert."
L["Enable Coordinates"] = "Koordinaten aktivieren"
L["Enable Hudmap"] = "Hudmap aktivieren"
L["Enable Minimap Fader"] = "Minikarten-Abblendung aktivieren"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "Füge einen Namen ein, um einen neuen Rahmen zu erstellen. Der Name soll dir helfen, den Rahmen zu identifizieren."
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "Füge den vollständigen Pfad der gewünschten Textur ein. Es wird empfohlen, dass du ein AddOn wie z.B. |cffff6600TexBrowser| benutzt, um nützliche Texturen zu suchen."
L["Entry Options"] = "Eintragsoptionen"
L["Faded Circle (Large)"] = "Verblasster Kreis (groß)"
L["Faded Circle (Small)"] = "Verblasster Kreis (klein)"
L["Faded Square"] = "Verblasster Kreis"
L["Fader"] = "Überblendregler"
L["Font"] = "Schrifttyp"
L["Font Color"] = "Schriftfarbe"
L["Font Size"] = "Schriftgröße"
L["Force a square texture. Fixed distortion on square textures."] = "Erzwinge eine rechteckige Textur. Feste Verformung von rechteckigen Texturen."
L["Garrison Button (When Available)"] = "Garnisonsknopf (Falls verfügbar)"
L["Guild Dungeon Difficulty Indicator (When Available)"] = "Gildeninstanzschwierigkeitsindikator (falls verfügbar)"
L["Heart"] = "Herz"
L["Height"] = "Höhe"
L["Hexagon"] = "Sechseck"
L["Hide default border"] = "Verstecke den Standardrahmen"
L["Hide the default border on the minimap."] = "Verstecke den Standardrahmen der Minikarte"
L["Horizontal Nudge"] = "Horizontaler Anstoß"
L["Horizontal Position"] = "Horizontale Position"
L["Hover Opacity"] = "MouseOver Transparenz"
L["HUD Color"] = "HUD-Farbe"
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "Wenn du in die Karte hineinzoomst, wird diese Funktion nach der eingestellten Zeit (in Sekunden) automatisch wieder herauszoomen. Wird der Wert 0 verwendet, wird das automatische Herauszoomen deaktiviert."
L["Keybinding"] = "Tastenbelegung"
L["Layer"] = "Ebene"
L["Let SexyMap control button visibility"] = "Ermögliche SexyMap die Kontrolle über die Sichtbarkeit der Minikartenknöpfe"
L["Let SexyMap handle button dragging"] = "Ermögliche SexyMap die Kontrolle über die Positionierung der Minikartenknöpfe"
L["Lock Button Dragging"] = "Ziehen der Knöpfe verhindern"
L["Lock Minimap"] = "Minikarte sperren"
L["Map Button"] = "Kartenknopf"
L["Minimap shape"] = "Form der Minikarte"
L["Mod Blend (modulative)"] = "Moderne Mischung (modulierbar)" -- Needs review
L["Movers"] = "Bewegliche Knöpfe"
L["Name"] = "Name"
L["Never"] = "Niemals"
L["New Mail Indicator (When Available)"] = "Neue-Post-Anzeige (wenn verfügbar)"
L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "Es existiert kein globales Profil. Das aktuelle Profil wird kopiert und als das globale Profil verwendet, bist du dir sicher? Dies wird auch dein Interface neu laden."
L["Normal Opacity"] = "Normale Transparenz"
L["Objectives Tracker"] = "Aufgabenliste"
L["Octagon"] = "Achteck"
L["On Hover"] = "bei Überfahren (mit der Maus)"
L["Opacity"] = "Deckkraft/Undurchsichtigkeit"
L["Open TexBrowser"] = "Öffne TexBrowser"
L["Ping"] = "Ping"
L["Preset"] = "Voreinstellung"
L["Prevent the minimap from being moved off the screen"] = "Verhindere, dass die Minikarte außerhalb des Bildschirms bewegt werden kann"
L["Profiles"] = "Profile"
L["Queue Status (PvP/LFG) Button (When Available)"] = "Warteschlangenstatus (PvP/LFG) Knopf (wenn verfügbar)"
L["Quickly change the look of your minimap by using a minimap preset."] = "Das Aussehen der Minikarte schnell ändern, indem eine Voreinstellung geladen wird"
L["Really delete this border?"] = "Diesen Rahmen wirklich entfernen?"
L["Really delete this preset? This can't be undone."] = "Diese Voreinstellung wirklich entfernen? Das Entfernen lässt sich nicht rückgängig machen!"
L["Really delete this profile?"] = "Dieses Profil wirklich löschen?"
L["(Requires button visibility control in the Buttons menu)"] = "Benötigt Knopf-Sichtbarkeits-Kontrolle im Knöpfe-Menü"
L["Reset Current Profile"] = "Aktuelles Profil zurücksetzen"
L["Resetting this profile will reload your UI, are you sure?"] = "Das Zurücksetzen dieses Profils wird dein Interface neu laden, bist du dir sicher?"
L["Right Click Configure"] = "Rechtsklick-Konfiguration"
L["Right clicking the map will open the SexyMap options"] = "Ein Rechtsklick auf die Minikarte öffnet die SexyMap-Optionen"
L["Rotation Speed (seconds)"] = "Rotationsgeschwindigkeit (Sekunden)"
L["Rounded - Bottom"] = "Abgerundet - Oben"
L["Rounded - Bottom Left"] = "Abgerundet - Unten Links"
L["Rounded - Bottom Right"] = "Abgerundet - Unten Rechts"
L["Rounded - Left"] = "Abgerundet - Links"
L["Rounded - Right"] = "Abgerundet - Rechts"
L["Rounded - Top"] = "Abgerundet - Unten"
L["Rounded - Top Left"] = "Abgerundet - Oben Links"
L["Rounded - Top Right"] = "Abgerundet - Oben Rechts"
L["Route 66"] = "Route 66"
L["Save current settings as preset..."] = "Speichere die aktuellen Einstellungen als Voreinstellung"
L["Scale"] = "Maßstab/Skalierung"
L["Select a preset to load settings from. This will erase any of your current borders."] = "Wähle eine Voreinstellung, um die Einstellungen zu laden. Dies wird alle deine aktuellen Rahmen löschen."
L["Select preset to load"] = "Wähle eine Voreinstellung"
L["SharedMedia Border"] = "SharedMedia-Rahmen"
L["SharedMedia Texture"] = "SharedMedia-Textur"
L["Show inside chat"] = "Zeige im Chat"
L["Show North Tag"] = "Zeige Norden-Anzeiger"
L["Show on minimap"] = "Zeige an der Minikarte"
L["Show %s:"] = "Zeige %s:"
L["Show who pinged"] = "Zeige wer gepingt hat"
L["Snowflake"] = "Schneeflocke"
L["Spice up your minimap with some sexy options."] = "Peppe deine Minikarte auf, mit ein paar sexy Optionen."
L["Square"] = "Rechteck"
L["Standard Buttons"] = "Standardknöpfe"
L["Static Rotation"] = "Statische Rotation"
L["TexBrowser Not Installed"] = "TexBrowser ist nicht installiert"
L["Text Color"] = "Textfarbe"
L["Texture"] = "Textur"
L["Texture Options"] = "Texturoptionen"
L["Texture Path"] = "Texturpfad"
L["Texture Tint"] = "Texturfarbton"
L["Text Width"] = "Textbreite"
L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "Die HudMap unterstützt einige Addons. Falls du eines der unten aufgeführten Addons installiert hast, werden sie auf der HudMap angezeigt."
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "Die Zeit für eine Rotation in Sekunden. Ist der Wert 0, wird die Rotation deaktiviert."
L["This will wipe out any current settings!"] = "Dies wird alle aktuellen Einstellungen löschen."
L["Tile Background"] = "Kachelhintergrund"
L["Tile Size"] = "Kachelgröße"
L["Toggle HudMap On/Off"] = "Schalte HudMap An/Aus"
L["Tracking Button"] = "Verfolgungsknopf"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "Deaktiviere diese Option, wenn du ein anderes Addon für die Sichtbarkeit der Minikartenknöpfe benutzt."
L["Use Global Profile"] = "Verwende das globale Profil"
L["User-Submitted Presets"] = "Voreinstellungen von Anwendern"
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "Verwende das globale Profil, wenn du das gleiche Aussehen für jeden Charakter haben willst, oder verwende ein Charakter spezifisches Profil, für ein einzigartiges Aussehen bei jedem Charakter."
L["Vehicle Seat"] = "Fahrzeugsitz"
L["Vertical Nudge"] = "Vertikaler Anschlag"
L["Vertical Position"] = "Vertikale Position"
L["Visibility"] = "Sichtbarkeit"
L["Width"] = "Breite"
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "Du kannst einen Hintergrund und Rahmen für die Minikarte einstellen, genauso wie bei allen anderen Rahmen. Dies ist nützlich, wenn du einen statischen rechteckigen Hintergrund für die Minikarte erstellen möchtest."
L["Zone Text"] = "Zonentext"
L["Zoom In Button"] = "Heranzoom-Knopf"
L["Zoom Out Button"] = "Herauszoom-Knopf"

-- Coordinates.lua
--L.updateRate = "Update Rate (seconds)"
--L.updateRateDesc = "The lower the value, the faster the coordinates will update, but the more memory and CPU will be consumed due to asking the game for fresh coordinate data."
--L.Precision = "Precision"

-- Movers.lua
--L.moversDescription = "Enable the ability to move specific UI elements."
--L.disableWarning = "Disabling this will temporarily show the loading screen. Are you sure?"
--L.enableObject = "Enable %s"
--L.lockObject = "Lock %s"
L.pvpCaptureBar = "PvP Aufnahmeleisten"
--L.buffs = "Buffs/Debuffs"
--L.topCenterObjectivesWidget = "Top-Screen Objective/PvP Tracker"

==> SexyMap-v12.0.2.zip: SexyMap/localization/deDE.lua <==

if GetLocale() ~= "deDE" then return end
local _, sm = ...
local L = sm.L
--L.dayNightButton = "Day/Night Indicator"
--L.classicLFGButton = "Classic LFG Button (When Available)"
--L.classicPVPButton = "Classic PvP Button (When Available)"
L["1. Background"] = "1. Hintergrund"
L["2. Border"] = "2. Rahmen"
L["3. Artwork"] = "3. Vorlagen"
L["4. Overlay"] = "4. Überlagerung"
L["5. Highlight"] = "5. Hervorhebung"
L["Add Blend (additive)"] = "Überblendung hinzufügen (additiv)"
L["Addon Buttons"] = "AddOn-Knöpfe"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "Ein globales Profil existiert bereits. Du wechselst auf dieses Profil und das Interface wird neu geladen, bist du dir sicher?"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "Erlaube SexyMap, das Bewegen/Ziehen von Knöpfen an der Minikarte zu übernehmen. Deaktiviere diese Option, wenn du einen anderen Mod/AddOn benutzt, um die Minikartenknöpfe zu positionieren."
L["Alpha Key (1-bit alpha)"] = "Alpha-Wert (1-bit alpha)"
L["Always"] = "Immer"
L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "Bist du dir sicher, dass du zurück auf das charakterspezifische Profil wechseln willst? Dies wird dein Interface neu laden."
L["Armored Man"] = "Haltbarkeitsfigur"
L["A static amount to rotate the texture by."] = "Ein statischer Wert, um den die Textur gedreht werden soll."
L["Auto Zoom-Out Delay"] = "Auto-Herauszoom-Verzögerung"
L["Backdrop Color"] = "Hintergrundfarbe"
L["Backdrop Insets"] = "Hintergründe"
L["Background Color"] = "Hintergrundfarbe"
L["Background/edge"] = "Hintergrund/Kante"
L["Background Texture"] = "Hintergrundtextur"
L["Blend Mode"] = "Überblendmodus"
L["Blend (normal)"] = "Überblendung (normal)"
L["Border Color"] = "Rahmenfarbe"
L["Border Edge Size"] = "Randkantengröße"
L["Borders"] = "Rahmen"
L["Border Texture"] = "Rahmentextur"
L["Boss Frames"] = "Bossfenster"
L["Buttons"] = "Knöpfe"
L["Calendar"] = "Kalender"
L["Challenge Mode Button (When Available)"] = "Herausforderungsmodus-Knopf (Wenn verfügbar)"
L["Circle"] = "Kreis"
L["Clamp to screen"] = "Am Bildschirm befestigen"
L["Clear & start over"] = "Leeren & neu anfangen"
L["Clear the current borders and start fresh"] = "Die aktuellen Rahmen löschen und neu anfangen"
L["Clock"] = "Uhr"
L["Coordinates"] = "Koordinaten"
L["Copy a Profile"] = "Kopiere ein Profil"
L["Copying this profile will reload your UI, are you sure?"] = "Das Kopieren dieses Profils wird dein Interface neu laden, bist du dir sicher?"
L["Create a new border"] = "Neuen Rahmen erstellen"
L["Current Borders"] = "Aktuelle Rahmen"
L["Default Presets"] = "Standard-Voreinstellungen"
L["Delete"] = "Löschen"
L["Delete a Profile"] = "Lösche ein Profil"
L["Diamond"] = "Diamant"
L["Disable (opaque)"] = "Deaktivieren (lichtdicht/opaque)"
L["Disable Rotation"] = "Rotation deaktivieren"
L["Drag Radius"] = "Bewegungs-Radius"
L["Dungeon Difficulty Indicator (When Available)"] = "Instanzschwierigkeitsanzeige (wenn verfügbar)"
L["Dynamic Buttons"] = "Dynamische Knöpfe"
L["Enable"] = "Aktivieren"
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "Aktiviere einen Hintergrund und Rahmen für die Minikarte. Dies erleichtert die Konfiguration von eckigen Rahmen."
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "Aktiviere eine HUD-Minikarte. Diese Anzeige ist sehr nützlich für Sammelberufe, jedoch kann das HUD und die normale Minikarte nicht gleichzeitig angezeigt werden. Die normale Minikarte ist während der HUD-Anzeige deaktiviert."
L["Enable Coordinates"] = "Koordinaten aktivieren"
L["Enable Hudmap"] = "Hudmap aktivieren"
L["Enable Minimap Fader"] = "Minikarten-Abblendung aktivieren"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "Füge einen Namen ein, um einen neuen Rahmen zu erstellen. Der Name soll dir helfen, den Rahmen zu identifizieren."
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "Füge den vollständigen Pfad der gewünschten Textur ein. Es wird empfohlen, dass du ein AddOn wie z.B. |cffff6600TexBrowser| benutzt, um nützliche Texturen zu suchen."
L["Entry Options"] = "Eintragsoptionen"
L["Faded Circle (Large)"] = "Verblasster Kreis (groß)"
L["Faded Circle (Small)"] = "Verblasster Kreis (klein)"
L["Faded Square"] = "Verblasster Kreis"
L["Fader"] = "Überblendregler"
L["Font"] = "Schrifttyp"
L["Font Color"] = "Schriftfarbe"
L["Font Size"] = "Schriftgröße"
L["Force a square texture. Fixed distortion on square textures."] = "Erzwinge eine rechteckige Textur. Feste Verformung von rechteckigen Texturen."
L["Garrison Button (When Available)"] = "Garnisonsknopf (Falls verfügbar)"
L["Guild Dungeon Difficulty Indicator (When Available)"] = "Gildeninstanzschwierigkeitsindikator (falls verfügbar)"
L["Heart"] = "Herz"
L["Height"] = "Höhe"
L["Hexagon"] = "Sechseck"
L["Hide default border"] = "Verstecke den Standardrahmen"
L["Hide the default border on the minimap."] = "Verstecke den Standardrahmen der Minikarte"
L["Horizontal Nudge"] = "Horizontaler Anstoß"
L["Horizontal Position"] = "Horizontale Position"
L["Hover Opacity"] = "MouseOver Transparenz"
L["HUD Color"] = "HUD-Farbe"
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "Wenn du in die Karte hineinzoomst, wird diese Funktion nach der eingestellten Zeit (in Sekunden) automatisch wieder herauszoomen. Wird der Wert 0 verwendet, wird das automatische Herauszoomen deaktiviert."
L["Keybinding"] = "Tastenbelegung"
L["Layer"] = "Ebene"
L["Let SexyMap control button visibility"] = "Ermögliche SexyMap die Kontrolle über die Sichtbarkeit der Minikartenknöpfe"
L["Let SexyMap handle button dragging"] = "Ermögliche SexyMap die Kontrolle über die Positionierung der Minikartenknöpfe"
L["Lock Button Dragging"] = "Ziehen der Knöpfe verhindern"
L["Lock Minimap"] = "Minikarte sperren"
L["Map Button"] = "Kartenknopf"
L["Minimap shape"] = "Form der Minikarte"
L["Mod Blend (modulative)"] = "Moderne Mischung (modulierbar)" -- Needs review
L["Movers"] = "Bewegliche Knöpfe"
L["Name"] = "Name"
L["Never"] = "Niemals"
L["New Mail Indicator (When Available)"] = "Neue-Post-Anzeige (wenn verfügbar)"
L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "Es existiert kein globales Profil. Das aktuelle Profil wird kopiert und als das globale Profil verwendet, bist du dir sicher? Dies wird auch dein Interface neu laden."
L["Normal Opacity"] = "Normale Transparenz"
L["Objectives Tracker"] = "Aufgabenliste"
L["Octagon"] = "Achteck"
L["On Hover"] = "bei Überfahren (mit der Maus)"
L["Opacity"] = "Deckkraft/Undurchsichtigkeit"
L["Open TexBrowser"] = "Öffne TexBrowser"
L["Ping"] = "Ping"
L["Preset"] = "Voreinstellung"
L["Prevent the minimap from being moved off the screen"] = "Verhindere, dass die Minikarte außerhalb des Bildschirms bewegt werden kann"
L["Profiles"] = "Profile"
L["Queue Status (PvP/LFG) Button (When Available)"] = "Warteschlangenstatus (PvP/LFG) Knopf (wenn verfügbar)"
L["Quickly change the look of your minimap by using a minimap preset."] = "Das Aussehen der Minikarte schnell ändern, indem eine Voreinstellung geladen wird"
L["Really delete this border?"] = "Diesen Rahmen wirklich entfernen?"
L["Really delete this preset? This can't be undone."] = "Diese Voreinstellung wirklich entfernen? Das Entfernen lässt sich nicht rückgängig machen!"
L["Really delete this profile?"] = "Dieses Profil wirklich löschen?"
L["(Requires button visibility control in the Buttons menu)"] = "Benötigt Knopf-Sichtbarkeits-Kontrolle im Knöpfe-Menü"
L["Reset Current Profile"] = "Aktuelles Profil zurücksetzen"
L["Resetting this profile will reload your UI, are you sure?"] = "Das Zurücksetzen dieses Profils wird dein Interface neu laden, bist du dir sicher?"
L["Right Click Configure"] = "Rechtsklick-Konfiguration"
L["Right clicking the map will open the SexyMap options"] = "Ein Rechtsklick auf die Minikarte öffnet die SexyMap-Optionen"
L["Rotation Speed (seconds)"] = "Rotationsgeschwindigkeit (Sekunden)"
L["Rounded - Bottom"] = "Abgerundet - Oben"
L["Rounded - Bottom Left"] = "Abgerundet - Unten Links"
L["Rounded - Bottom Right"] = "Abgerundet - Unten Rechts"
L["Rounded - Left"] = "Abgerundet - Links"
L["Rounded - Right"] = "Abgerundet - Rechts"
L["Rounded - Top"] = "Abgerundet - Unten"
L["Rounded - Top Left"] = "Abgerundet - Oben Links"
L["Rounded - Top Right"] = "Abgerundet - Oben Rechts"
L["Route 66"] = "Route 66"
L["Save current settings as preset..."] = "Speichere die aktuellen Einstellungen als Voreinstellung"
L["Scale"] = "Maßstab/Skalierung"
L["Select a preset to load settings from. This will erase any of your current borders."] = "Wähle eine Voreinstellung, um die Einstellungen zu laden. Dies wird alle deine aktuellen Rahmen löschen."
L["Select preset to load"] = "Wähle eine Voreinstellung"
L["SharedMedia Border"] = "SharedMedia-Rahmen"
L["SharedMedia Texture"] = "SharedMedia-Textur"
L["Show inside chat"] = "Zeige im Chat"
L["Show North Tag"] = "Zeige Norden-Anzeiger"
L["Show on minimap"] = "Zeige an der Minikarte"
L["Show %s:"] = "Zeige %s:"
L["Show who pinged"] = "Zeige wer gepingt hat"
L["Snowflake"] = "Schneeflocke"
L["Spice up your minimap with some sexy options."] = "Peppe deine Minikarte auf, mit ein paar sexy Optionen."
L["Square"] = "Rechteck"
L["Standard Buttons"] = "Standardknöpfe"
L["Static Rotation"] = "Statische Rotation"
L["TexBrowser Not Installed"] = "TexBrowser ist nicht installiert"
L["Text Color"] = "Textfarbe"
L["Texture"] = "Textur"
L["Texture Options"] = "Texturoptionen"
L["Texture Path"] = "Texturpfad"
L["Texture Tint"] = "Texturfarbton"
L["Text Width"] = "Textbreite"
L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "Die HudMap unterstützt einige Addons. Falls du eines der unten aufgeführten Addons installiert hast, werden sie auf der HudMap angezeigt."
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "Die Zeit für eine Rotation in Sekunden. Ist der Wert 0, wird die Rotation deaktiviert."
L["This will wipe out any current settings!"] = "Dies wird alle aktuellen Einstellungen löschen."
L["Tile Background"] = "Kachelhintergrund"
L["Tile Size"] = "Kachelgröße"
L["Toggle HudMap On/Off"] = "Schalte HudMap An/Aus"
L["Tracking Button"] = "Verfolgungsknopf"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "Deaktiviere diese Option, wenn du ein anderes Addon für die Sichtbarkeit der Minikartenknöpfe benutzt."
L["Use Global Profile"] = "Verwende das globale Profil"
L["User-Submitted Presets"] = "Voreinstellungen von Anwendern"
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "Verwende das globale Profil, wenn du das gleiche Aussehen für jeden Charakter haben willst, oder verwende ein Charakter spezifisches Profil, für ein einzigartiges Aussehen bei jedem Charakter."
L["Vehicle Seat"] = "Fahrzeugsitz"
L["Vertical Nudge"] = "Vertikaler Anschlag"
L["Vertical Position"] = "Vertikale Position"
L["Visibility"] = "Sichtbarkeit"
L["Width"] = "Breite"
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "Du kannst einen Hintergrund und Rahmen für die Minikarte einstellen, genauso wie bei allen anderen Rahmen. Dies ist nützlich, wenn du einen statischen rechteckigen Hintergrund für die Minikarte erstellen möchtest."
L["Zone Text"] = "Zonentext"
L["Zoom In Button"] = "Heranzoom-Knopf"
L["Zoom Out Button"] = "Herauszoom-Knopf"

-- Buttons.lua
--L.addonCompartment = "Addon Compartment"
--L.craftingOrder = "Crafting Order (When Available)"

-- Coordinates.lua
--L.updateRate = "Update Rate (seconds)"
--L.updateRateDesc = "The lower the value, the faster the coordinates will update, but the more memory and CPU will be consumed due to asking the game for fresh coordinate data."
--L.Precision = "Precision"

-- Movers.lua
--L.moversDescription = "Enable the ability to move specific UI elements."
--L.disableWarning = "Disabling this will temporarily show the loading screen. Are you sure?"
--L.enableObject = "Enable %s"
--L.lockObject = "Lock %s"
L.pvpCaptureBar = "PvP Aufnahmeleisten"
--L.buffs = "Buffs/Debuffs"
--L.topCenterObjectivesWidget = "Top-Screen Objective/PvP Tracker"
--L.zoneTextCombatClick = "|cFF33FF99SexyMap|r: To toggle the World Map in combat, you must enable the feature in the Zone Text options."
--L.zoneTextSecureButtonEnable = "Allow clicking in combat"
--L.zoneTextSecureButtonEnableDesc = "Normally you can click the Zone Text to toggle your World Map, but not in combat without this feature enabled.\n\n|cffff0000WARNING!|r Don't enable this feature unless you understand what it does. Turning this on will prevent ALL of your addons from making certain changes to your minimap in combat, such as moving it or hiding it."
L.none = "Nichts"
L.thin = "Dünn"
L.thick = "Dick"
L.outline = "Kontur"
L.monochrome = "Monochrom"
L.monochromeDesc = "Schaltet den Monochrom-Filter an/aus, der die Schriftenkantenglättung entfernt."
